==> smartgwt-6.1p.zip: com/smartgwt/logicalstructure/widgets/tile/TileGridLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.tile;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class TileGridLogicalStructure extends TileLayoutLogicalStructure {
    public String animateTileChange;
    public String canAcceptDroppedRecords;
    public String canDragTilesOut;
    public String canReorderTiles;
    public String dataFetchMode;
    public String drawAllMaxTiles;
    public String emptyMessage;
    public String emptyMessageStyle;
    public String loadingMessage;
    public String printTilesPerLine;
    public String recycleTiles;
    public String selectionType;
    public String showAllRecords;
    public String showDetailFields;
    public String showEmptyMessage;
    public String styleName;
    public String tileConstructor;
    public String tileDragAppearance;
    public Canvas[] tiles;
    public String tileValueAlign;
    public String tileValueStyle;
    public String valuesShowDown;
    public String valuesShowRollOver;
    public String valuesShowSelected;
    public String wrapValues;
}

==> smartgwt-13.0p.zip: com/smartgwt/logicalstructure/widgets/tile/TileGridLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.tile;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class TileGridLogicalStructure extends TileLayoutLogicalStructure {
    public String animateTileChange;
    public String canAcceptDroppedRecords;
    public String canDragTilesOut;
    public String canReorderTiles;
    public String dataArity;
    public String dataFetchMode;
    public String drawAllMaxTiles;
    public String editProxyConstructor;
    public String emptyMessage;
    public String emptyMessageStyle;
    public String loadingDataMessage;
    public String loadingDataMessageStyle;
    public String loadingMessage;
    public String printTilesPerLine;
    public String recycleTiles;
    public String reselectOnUpdate;
    public String reselectOnUpdateNotifications;
    public String selectionType;
    public String showAllRecords;
    public String showDetailFields;
    public String showEmptyMessage;
    public String styleName;
    public String tileConstructor;
    public String tileDragAppearance;
    public Canvas[] tiles;
    public String tileScreen;
    public String tileValueAlign;
    public String tileValueStyle;
    public String valuesShowDown;
    public String valuesShowRollOver;
    public String valuesShowSelected;
    public String wrapValues;
}
